@@ -359,7 +359,9 @@ procman_data_new (GConfClient *client)
 	pd->config.graph_update_interval = MAX (pd->config.graph_update_interval, 250);
 	pd->config.disks_update_interval = MAX (pd->config.disks_update_interval, 1000);
 	pd->config.whose_process = CLAMP (pd->config.whose_process, 0, 2);
-	pd->config.current_tab = CLAMP (pd->config.current_tab, 0, 2);
+	pd->config.current_tab = CLAMP(pd->config.current_tab,
+				       PROCMAN_TAB_SYSINFO,
+				       PROCMAN_TAB_DISKS);
 	
 	/* Determinie number of cpus since libgtop doesn't really tell you*/
 	pd->config.num_cpus = 0;
@@ -538,9 +540,9 @@ procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *pref
 
 		if(!gconf_client_set_list(client, key, GCONF_VALUE_INT, order, &error))
 		{
-			g_error("Could not save GConf key '%s' : %s",
-				key,
-				error->message);
+			g_critical("Could not save GConf key '%s' : %s",
+				   key,
+				   error->message);
 			g_error_free(error);
 		}
 
@@ -659,7 +661,7 @@ main (int argc, char *argv[])
 	ProcData *procdata;
 	BaconMessageConnection *conn;
 
-	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
@@ -692,7 +694,7 @@ main (int argc, char *argv[])
 		exit (0);
 	}
 
-	gtk_window_set_default_icon_name ("gnome-monitor");
+	gtk_window_set_default_icon_name ("utilities-system-monitor");
 	g_set_application_name(_("System Monitor"));
 		    
 	gconf_init (argc, argv, NULL);
