@@ -50,6 +50,15 @@ enum
 };
 
 
+enum ProcmanTab
+{
+	PROCMAN_TAB_SYSINFO,
+	PROCMAN_TAB_PROCESSES,
+	PROCMAN_TAB_RESOURCES,
+	PROCMAN_TAB_DISKS
+};
+
+
 struct _ProcConfig
 {
 	gint		width;
@@ -82,6 +91,7 @@ struct _ProcInfo
 	GSList		*children;
 
 	GdkPixbuf	*pixbuf;
+	gchar		*tooltip;
 	gchar		*name;
 	gchar		*user; /* allocated with g_string_chunk, don't free it ! */
 	gchar		*arguments;
